@@ -1,6 +1,6 @@
 use std::{
   collections::{BTreeMap, BTreeSet, HashMap, VecDeque},
-  ops::Bound::*,
+  ops::Bound,
 };
 
 use log::debug;
@@ -143,7 +143,7 @@ where
       {
         instance_metadata
           .latest_generation_available
-          .disposed_generation_count += 1
+          .disposed_generation_count += 1;
       }
 
       (InstanceState::NotAliveDisposed, _) => (), // you can only die once
@@ -153,7 +153,7 @@ where
       {
         instance_metadata
           .latest_generation_available
-          .no_writers_generation_count += 1
+          .no_writers_generation_count += 1;
       }
 
       (InstanceState::NotAliveNoWriters, _) => (), // you can only die once
@@ -180,7 +180,7 @@ where
           panic!(
             "Tried to add duplicate datasample with the same key {:?}",
             receive_timestamp
-          )
+          );
         },
       );
 
@@ -208,7 +208,7 @@ where
           .instance_samples
           .iter()
           .take(remove_count as usize)
-          .cloned()
+          .copied()
           .collect();
         for k in keys_to_remove {
           instance_metadata.instance_samples.remove(&k);
@@ -242,10 +242,10 @@ where
 
   pub fn select_instance_keys_for_access(
     &self,
-    instance: D::K,
+    instance: &D::K,
     rc: ReadCondition,
   ) -> Vec<(Timestamp, D::K)> {
-    match self.instance_map.get(&instance) {
+    match self.instance_map.get(instance) {
       None => Vec::new(),
       Some(imd) => imd
         .instance_samples
@@ -332,7 +332,7 @@ where
       .entry(instance_key.clone())
       .and_modify(|old_gens| {
         if accessed_generations.total() > old_gens.total() {
-          *old_gens = accessed_generations
+          *old_gens = accessed_generations;
         }
       })
       .or_insert(accessed_generations);
@@ -340,13 +340,13 @@ where
 
   fn mark_instances_viewed(
     &mut self,
-    instance_generations: HashMap<D::K, NotAliveGenerationCounts>,
+    instance_generations: &HashMap<D::K, NotAliveGenerationCounts>,
   ) {
-    for (inst, gen) in instance_generations.iter() {
+    for (inst, gen) in instance_generations {
       if let Some(imd) = self.instance_map.get_mut(inst) {
         imd.last_generation_accessed = *gen;
       } else {
-        panic!("Instance disappeared!?!!1!")
+        panic!("Instance disappeared!?!!1!");
       }
     }
   }
@@ -397,7 +397,7 @@ where
     }
 
     // mark instances viewed
-    self.mark_instances_viewed(instance_generations);
+    self.mark_instances_viewed(&instance_generations);
 
     // We need to do SampleInfo construction and final result construction as
     // separate passes. This is becaue SampleInfo construction needs to mark
@@ -457,7 +457,7 @@ where
       result.push(DataSample::new(sample_info, dswm.sample));
     }
 
-    self.mark_instances_viewed(instance_generations);
+    self.mark_instances_viewed(&instance_generations);
     result
   }
 
@@ -485,7 +485,7 @@ where
       );
     }
 
-    self.mark_instances_viewed(instance_generations);
+    self.mark_instances_viewed(&instance_generations);
 
     // We need to do SampleInfo construction and final result construction as
     // separate passes. See reason in read function above.
@@ -524,7 +524,7 @@ where
       result.push(dswm.sample);
     }
 
-    self.mark_instances_viewed(instance_generations);
+    self.mark_instances_viewed(&instance_generations);
     result
   }
 
@@ -550,13 +550,13 @@ where
   pub fn next_key(&self, key: &D::K) -> Option<D::K> {
     self
       .instance_map
-      .range((Excluded(key), Unbounded))
+      .range((Bound::Excluded(key), Bound::Unbounded))
       .map(|(k, _)| k.clone())
       .next()
   }
 
   pub fn set_qos_policy(&mut self, qos: QosPolicies) {
-    self.qos = qos
+    self.qos = qos;
   }
 }
 
