@@ -28,7 +28,7 @@ use crate::structure::sequence_number::SequenceNumber;
 
 const RTPS_MESSAGE_HEADER_SIZE: usize = 20;
 
-/// MessageReceiver is the submessage sequence interpreter described in
+/// [`MessageReceiver`] is the submessage sequence interpreter described in
 /// RTPS spec v2.3 Section 8.3.4 "The RTPS Message Receiver".
 /// It calls the message/submessage deserializers to parse the sequence of
 /// submessages. Then it processes the instructions in the Interpreter
@@ -110,8 +110,8 @@ impl MessageReceiver {
     let eid = new_reader.guid().entity_id;
     match self.available_readers.entry(eid) {
       Entry::Occupied(_) => warn!("Already have Reader {:?} - not adding.", eid),
-      e => {
-        e.or_insert(new_reader);
+      Entry::Vacant(e) => {
+        e.insert(new_reader);
       }
     }
   }
@@ -175,7 +175,7 @@ impl MessageReceiver {
   //   self.handle_user_msg(msg);
   // }
 
-  pub fn handle_received_packet(&mut self, msg_bytes: Bytes) {
+  pub fn handle_received_packet(&mut self, msg_bytes: &Bytes) {
     // Check for RTPS ping message. At least RTI implementation sends these.
     // What should we do with them? The spec does not say.
     if msg_bytes.len() < RTPS_MESSAGE_HEADER_SIZE {
@@ -195,7 +195,7 @@ impl MessageReceiver {
 
     // call Speedy reader
     // Bytes .clone() is cheap, so no worries
-    let rtps_message = match Message::read_from_buffer(msg_bytes.clone()) {
+    let rtps_message = match Message::read_from_buffer(msg_bytes) {
       Ok(m) => m,
       Err(speedy_err) => {
         warn!("RTPS deserialize error {:?}", speedy_err);
@@ -205,7 +205,7 @@ impl MessageReceiver {
     };
 
     // And process message
-    self.handle_parsed_message(rtps_message)
+    self.handle_parsed_message(rtps_message);
   }
 
   // This is also called directly from dp_event_loop in case of loopback messages.
@@ -259,10 +259,10 @@ impl MessageReceiver {
               "handle_entity_submessage DATA from unknown handling in {:?}",
               &reader
             );
-            reader.handle_data_msg(data.clone(), data_flags, mr_state.clone());
+            reader.handle_data_msg(data.clone(), data_flags, &mr_state);
           }
         } else if let Some(target_reader) = self.reader_mut(data.reader_id) {
-          target_reader.handle_data_msg(data, data_flags, mr_state);
+          target_reader.handle_data_msg(data, data_flags, &mr_state);
         }
         // bypass lane fro SPDP messages
         if writer_entity_id == EntityId::SPDP_BUILTIN_PARTICIPANT_WRITER {
@@ -273,7 +273,7 @@ impl MessageReceiver {
               debug!(
                 "spdp_liveness_sender.try_send(): {:?}. Is Discovery alive?",
                 e
-              )
+              );
             });
         }
       }
@@ -287,14 +287,14 @@ impl MessageReceiver {
             .filter(|p| p.contains_writer(heartbeat.writer_id))
           {
             reader.handle_heartbeat_msg(
-              heartbeat.clone(),
+              &heartbeat,
               flags.contains(HEARTBEAT_Flags::Final),
               mr_state.clone(),
             );
           }
         } else if let Some(target_reader) = self.reader_mut(heartbeat.reader_id) {
           target_reader.handle_heartbeat_msg(
-            heartbeat,
+            &heartbeat,
             flags.contains(HEARTBEAT_Flags::Final),
             mr_state,
           );
@@ -302,7 +302,7 @@ impl MessageReceiver {
       }
       EntitySubmessage::Gap(gap, _flags) => {
         if let Some(target_reader) = self.reader_mut(gap.reader_id) {
-          target_reader.handle_gap_msg(gap, mr_state);
+          target_reader.handle_gap_msg(&gap, &mr_state);
         }
       }
       EntitySubmessage::AckNack(acknack, _) => {
@@ -314,14 +314,14 @@ impl MessageReceiver {
         {
           Ok(_) => (),
           Err(TrySendError::Full(_)) => {
-            info!("AckNack pipe full. Looks like I am very busy. Discarding submessage.")
+            info!("AckNack pipe full. Looks like I am very busy. Discarding submessage.");
           }
           Err(e) => warn!("AckNack pipe fail: {:?}", e),
         }
       }
       EntitySubmessage::DataFrag(datafrag, flags) => {
         if let Some(target_reader) = self.reader_mut(datafrag.reader_id) {
-          target_reader.handle_datafrag_msg(datafrag, flags, mr_state);
+          target_reader.handle_datafrag_msg(&datafrag, flags, &mr_state);
         }
       }
       EntitySubmessage::HeartbeatFrag(heartbeatfrag, _flags) => {
@@ -333,10 +333,10 @@ impl MessageReceiver {
             .values_mut()
             .filter(|p| p.contains_writer(heartbeatfrag.writer_id))
           {
-            reader.handle_heartbeatfrag_msg(heartbeatfrag.clone(), mr_state.clone());
+            reader.handle_heartbeatfrag_msg(&heartbeatfrag, &mr_state);
           }
         } else if let Some(target_reader) = self.reader_mut(heartbeatfrag.reader_id) {
-          target_reader.handle_heartbeatfrag_msg(heartbeatfrag, mr_state);
+          target_reader.handle_heartbeatfrag_msg(&heartbeatfrag, &mr_state);
         }
       }
       EntitySubmessage::NackFrag(_, _) => {}
@@ -371,10 +371,10 @@ impl MessageReceiver {
         }
       }
       InterpreterSubmessage::InfoDestination(info_dest, _flags) => {
-        if info_dest.guid_prefix != GUID::GUID_UNKNOWN.guid_prefix {
-          self.dest_guid_prefix = info_dest.guid_prefix;
-        } else {
+        if info_dest.guid_prefix == GUID::GUID_UNKNOWN.guid_prefix {
           self.dest_guid_prefix = self.own_guid_prefix;
+        } else {
+          self.dest_guid_prefix = info_dest.guid_prefix;
         }
       }
     }
@@ -385,14 +385,14 @@ impl MessageReceiver {
       self
         .available_readers
         .get(&eid)
-        .map(|r| r.notify_cache_change());
+        .map(Reader::notify_cache_change);
     }
   }
 
   // sends 0 seqnum acknacks for those writer that haven't had any action
   pub fn send_preemptive_acknacks(&mut self) {
     for reader in self.available_readers.values_mut() {
-      reader.send_preemptive_acknacks()
+      reader.send_preemptive_acknacks();
     }
   }
 } // impl messageReceiver
@@ -516,7 +516,7 @@ mod tests {
     //new_reader.matched_writer_add(remote_writer_guid, mr_state);
     message_receiver.add_reader(new_reader);
 
-    message_receiver.handle_received_packet(udp_bits1);
+    message_receiver.handle_received_packet(&udp_bits1);
 
     assert_eq!(message_receiver.submessage_count, 4);
 
@@ -606,10 +606,10 @@ mod tests {
     let mut message_receiver =
       MessageReceiver::new(guid_new.guid_prefix, acknack_sender, spdp_liveness_sender);
 
-    message_receiver.handle_received_packet(udp_bits1);
+    message_receiver.handle_received_packet(&udp_bits1);
     assert_eq!(message_receiver.submessage_count, 4);
 
-    message_receiver.handle_received_packet(udp_bits2);
+    message_receiver.handle_received_packet(&udp_bits2);
     assert_eq!(message_receiver.submessage_count, 2);
   }
 
