@@ -7,13 +7,10 @@ use std::{
 use log::{debug, error, trace, warn};
 
 use crate::{
-  dds::qos::QosPolicies,
+  dds::{participant::DomainParticipant, qos::QosPolicies},
   discovery::data_types::topic_data::DiscoveredReaderData,
   messages::submessages::submessage::AckSubmessage,
-  network::{
-    constant::{user_traffic_multicast_port, user_traffic_unicast_port},
-    util::{get_local_multicast_locators, get_local_unicast_locators},
-  },
+  network::constant::*,
   structure::{
     guid::{EntityId, EntityKind, GUID},
     locator::Locator,
@@ -80,14 +77,15 @@ impl RtpsReaderProxy {
 
   pub fn from_reader(
     reader: &ReaderIngredients,
-    domain_id: u16,
-    participant_id: u16,
+    domain_participant: &DomainParticipant,
   ) -> RtpsReaderProxy {
-    let unicast_locator_list =
-      get_local_unicast_locators(user_traffic_unicast_port(domain_id, participant_id));
-
-    let multicast_locator_list =
-      get_local_multicast_locators(user_traffic_multicast_port(domain_id));
+    let mut self_locators = domain_participant.self_locators(); // This clones a map of locator lists.
+    let unicast_locator_list = self_locators
+      .remove(&USER_TRAFFIC_LISTENER_TOKEN)
+      .unwrap_or_default();
+    let multicast_locator_list = self_locators
+      .remove(&USER_TRAFFIC_MUL_LISTENER_TOKEN)
+      .unwrap_or_default();
 
     RtpsReaderProxy {
       remote_reader_guid: reader.guid,
@@ -113,16 +111,16 @@ impl RtpsReaderProxy {
 
   pub fn from_discovered_reader_data(
     discovered_reader_data: &DiscoveredReaderData,
-    default_unicast_locators: Vec<Locator>,
-    default_multicast_locators: Vec<Locator>,
+    default_unicast_locators: &[Locator],
+    default_multicast_locators: &[Locator],
   ) -> RtpsReaderProxy {
     let unicast_locator_list = Self::discovered_or_default(
       &discovered_reader_data.reader_proxy.unicast_locator_list,
-      &default_unicast_locators,
+      default_unicast_locators,
     );
     let multicast_locator_list = Self::discovered_or_default(
       &discovered_reader_data.reader_proxy.multicast_locator_list,
-      &default_multicast_locators,
+      default_multicast_locators,
     );
 
     RtpsReaderProxy {
@@ -205,7 +203,7 @@ impl RtpsReaderProxy {
 
       AckSubmessage::NackFrag(_nack_frag) => {
         // TODO
-        error!("NACKFRAG not implemented")
+        error!("NACKFRAG not implemented");
       }
     }
   }
