@@ -75,7 +75,7 @@ pub type DataWriterCdr<D> = DataWriter<D, CDRSerializerAdapter<D>>;
 ///
 /// // WithKey is important
 /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-/// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None);
+/// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(&topic, None);
 /// ```
 pub struct DataWriter<D: Keyed + Serialize, SA: SerializerAdapter<D> = CDRSerializerAdapter<D>> {
   my_publisher: Publisher,
@@ -104,7 +104,7 @@ where
 
       // This is fairly normal at shutdown, as the other end is down already.
       Err(SendError::Disconnected(_cmd)) => {
-        debug!("Failed to send REMOVE_LOCAL_WRITER DiscoveryCommand: Disconnected.")
+        debug!("Failed to send REMOVE_LOCAL_WRITER DiscoveryCommand: Disconnected.");
       }
       // other errors must be taken more seriously
       Err(e) => error!(
@@ -153,16 +153,12 @@ where
 
     if let Some(lv) = topic.qos().liveliness {
       match lv {
-        Liveliness::Automatic { lease_duration: _ } => (),
-        Liveliness::ManualByParticipant { lease_duration: _ } => {
-          match discovery_command.send(DiscoveryCommand::ManualAssertLiveliness) {
-            Ok(_) => (),
-            Err(e) => {
-              error!("Failed to send DiscoveryCommand - Refresh. {:?}", e);
-            }
+        Liveliness::Automatic { .. } | Liveliness::ManualByTopic { .. } => (),
+        Liveliness::ManualByParticipant { .. } => {
+          if let Err(e) = discovery_command.send(DiscoveryCommand::ManualAssertLiveliness) {
+            error!("Failed to send DiscoveryCommand - Refresh. {:?}", e);
           }
         }
-        Liveliness::ManualByTopic { lease_duration: _ } => (),
       }
     };
     let qos = topic.qos();
@@ -214,7 +210,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
+  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// data_writer.refresh_manual_liveliness();
   /// ```
@@ -223,19 +219,15 @@ where
   pub fn refresh_manual_liveliness(&self) {
     if let Some(lv) = self.qos().liveliness {
       match lv {
-        Liveliness::Automatic { lease_duration: _ } => (),
-        Liveliness::ManualByParticipant { lease_duration: _ } => {
-          match self
+        Liveliness::Automatic { .. } | Liveliness::ManualByTopic { .. } => (),
+        Liveliness::ManualByParticipant { .. } => {
+          if let Err(e) = self
             .discovery_command
             .send(DiscoveryCommand::ManualAssertLiveliness)
           {
-            Ok(_) => (),
-            Err(e) => {
-              error!("Failed to send DiscoveryCommand - Refresh. {:?}", e);
-            }
+            error!("Failed to send DiscoveryCommand - Refresh. {:?}", e);
           }
         }
-        Liveliness::ManualByTopic { lease_duration: _ } => (),
       }
     };
   }
@@ -269,7 +261,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
+  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// let some_data = SomeType { a: 1 };
   /// data_writer.write(some_data, None).unwrap();
@@ -350,7 +342,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
+  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// let some_data = SomeType { a: 1 };
   /// data_writer.write(some_data, None).unwrap();
@@ -358,8 +350,7 @@ where
   /// ```
   pub fn wait_for_acknowledgments(&self, max_wait: Duration) -> Result<bool> {
     match &self.qos_policy.reliability {
-      None => Ok(true),
-      Some(Reliability::BestEffort) => Ok(true),
+      None | Some(Reliability::BestEffort) => Ok(true),
       Some(Reliability::Reliable { .. }) => {
         let (acked_sender, acked_receiver) = mio_channel::sync_channel::<()>(1);
         let poll = Poll::new()?;
@@ -655,7 +646,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic.clone(), None).unwrap();
+  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// assert_eq!(data_writer.topic(), &topic);
   /// ```
@@ -692,7 +683,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
+  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// assert_eq!(data_writer.publisher(), &publisher);
   pub fn publisher(&self) -> &Publisher {
@@ -728,7 +719,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
+  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// data_writer.assert_liveliness().unwrap();
   /// ```
@@ -747,7 +738,7 @@ where
             writer_guid: self.guid(),
             manual_assertion: true, // by definition of this function
           })
-          .unwrap_or_else(|e| error!("assert_liveness - Failed to send DiscoveryCommand. {:?}", e))
+          .unwrap_or_else(|e| error!("assert_liveness - Failed to send DiscoveryCommand. {:?}", e));
       }
       _other => (),
     }
@@ -786,7 +777,7 @@ where
   /// let topic = domain_participant.create_topic("some_topic".to_string(),
   /// "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
   /// let data_writer = publisher.create_datawriter::<SomeType,
-  /// CDRSerializerAdapter<_>>(topic, None).unwrap();
+  /// CDRSerializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// for sub in data_writer.get_matched_subscriptions().iter() {
   ///   // do something
@@ -830,7 +821,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None).unwrap();
+  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// let some_data_1_1 = SomeType { a: 1, val: 3};
   /// let some_data_1_2 = SomeType { a: 1, val: 4};
@@ -844,10 +835,10 @@ where
   /// data_writer.write(some_data_2_2, None).unwrap();
   ///
   /// // disposes both some_data_1_1 and some_data_1_2. They are no longer offered by this writer to this topic.
-  /// data_writer.dispose(1, None).unwrap();
+  /// data_writer.dispose(&1, None).unwrap();
   /// ```
-  pub fn dispose(&self, key: <D as Keyed>::K, source_timestamp: Option<Timestamp>) -> Result<()> {
-    let send_buffer = SA::key_to_bytes(&key)?; // serialize key
+  pub fn dispose(&self, key: &<D as Keyed>::K, source_timestamp: Option<Timestamp>) -> Result<()> {
+    let send_buffer = SA::key_to_bytes(key)?; // serialize key
 
     let ddsdata = DDSData::new_disposed_by_key(
       ChangeKind::NotAliveDisposed,
@@ -946,7 +937,7 @@ mod tests {
 
     let data_writer: DataWriter<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>> =
       publisher
-        .create_datawriter(topic, None)
+        .create_datawriter(&topic, None)
         .expect("Failed to create datawriter");
 
     let mut data = RandomData {
@@ -986,7 +977,7 @@ mod tests {
 
     let data_writer: DataWriter<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>> =
       publisher
-        .create_datawriter(topic, None)
+        .create_datawriter(&topic, None)
         .expect("Failed to create datawriter");
 
     let data = RandomData {
@@ -1003,7 +994,7 @@ mod tests {
 
     thread::sleep(Duration::from_millis(100));
     data_writer
-      .dispose(data.key(), None)
+      .dispose(&data.key(), None)
       .expect("Unable to dispose data");
 
     // TODO: verify that dispose is sent correctly
@@ -1027,7 +1018,7 @@ mod tests {
 
     let data_writer: DataWriter<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>> =
       publisher
-        .create_datawriter(topic, None)
+        .create_datawriter(&topic, None)
         .expect("Failed to create datawriter");
 
     let data = RandomData {
@@ -1040,7 +1031,7 @@ mod tests {
     let res = data_writer
       .wait_for_acknowledgments(Duration::from_secs(2))
       .unwrap();
-    assert!(res) // we should get "true" immediately, because we have
-                 // no Reliable QoS
+    assert!(res); // we should get "true" immediately, because we have
+                  // no Reliable QoS
   }
 }
