@@ -132,7 +132,7 @@ impl DiscoveryDB {
       }
       *ts = now;
     } else {
-      info!("Participant alive update for unknown {:?}. This is normal, if the message does not repeat.", guid_prefix)
+      info!("Participant alive update for unknown {:?}. This is normal, if the message does not repeat.", guid_prefix);
     }
   }
 
@@ -346,8 +346,8 @@ impl DiscoveryDB {
           data.clone(),
           RtpsReaderProxy::from_discovered_reader_data(
             data,
-            default_locator_lists.0,
-            default_locator_lists.1,
+            &default_locator_lists.0,
+            &default_locator_lists.1,
           ),
         ))
       }
@@ -442,7 +442,7 @@ impl DiscoveryDB {
     let topic_name = data.topic_data.name.clone();
 
     if let Some(t) = self.topics.get_mut(&data.topic_data.name) {
-      *t = data.clone()
+      *t = data.clone();
     } else {
       self.topics.insert(topic_name, data.clone());
       if let Some(c) = &self.event_sender {
@@ -462,11 +462,7 @@ impl DiscoveryDB {
   ) {
     let reader_guid = reader.guid;
 
-    let reader_proxy = RtpsReaderProxy::from_reader(
-      reader,
-      domain_participant.domain_id(),
-      domain_participant.participant_id(),
-    );
+    let reader_proxy = RtpsReaderProxy::from_reader(reader, domain_participant);
 
     let mut subscription_data = SubscriptionBuiltinTopicData::new(
       reader_guid,
@@ -552,7 +548,7 @@ impl DiscoveryDB {
       .collect()
   }
 
-  pub fn update_lease_duration(&mut self, data: ParticipantMessageData) {
+  pub fn update_lease_duration(&mut self, data: &ParticipantMessageData) {
     let now = Instant::now();
     let prefix = data.guid;
     self
@@ -590,7 +586,7 @@ mod tests {
 
   #[test]
   fn discdb_participant_operations() {
-    let mut discoverydb = DiscoveryDB::new(GUID::new_particiapnt_guid(), None);
+    let mut discoverydb = DiscoveryDB::new(GUID::new_participant_guid(), None);
     let mut data = spdp_participant_data().unwrap();
     data.lease_duration = Some(Duration::from(StdDuration::from_secs(1)));
 
@@ -609,7 +605,7 @@ mod tests {
 
   #[test]
   fn discdb_writer_proxies() {
-    let _discoverydb = DiscoveryDB::new(GUID::new_particiapnt_guid(), None);
+    let _discoverydb = DiscoveryDB::new(GUID::new_participant_guid(), None);
     let topic_name = String::from("some_topic");
     let type_name = String::from("RandomData");
     let _dreader = DiscoveredReaderData::default(topic_name, type_name);
@@ -619,7 +615,7 @@ mod tests {
 
   #[test]
   fn discdb_subscription_operations() {
-    let mut discovery_db = DiscoveryDB::new(GUID::new_particiapnt_guid(), None);
+    let mut discovery_db = DiscoveryDB::new(GUID::new_participant_guid(), None);
 
     let domain_participant = DomainParticipant::new(0).expect("Failed to create publisher");
     let topic = domain_participant
@@ -643,10 +639,7 @@ mod tests {
       .create_publisher(&QosPolicies::qos_none())
       .unwrap();
     let dw = publisher1
-      .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(
-        topic.clone(),
-        None,
-      )
+      .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(&topic, None)
       .unwrap();
 
     let writer_data = DiscoveredWriterData::new(&dw, &topic, &domain_participant);
@@ -659,10 +652,7 @@ mod tests {
       .create_publisher(&QosPolicies::qos_none())
       .unwrap();
     let dw2 = publisher2
-      .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(
-        topic.clone(),
-        None,
-      )
+      .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(&topic, None)
       .unwrap();
     let writer_data2 = DiscoveredWriterData::new(&dw2, &topic, &domain_participant);
     let _writer2_key = writer_data2.writer_proxy.remote_writer_guid;
@@ -715,7 +705,7 @@ mod tests {
         TopicKind::WithKey,
       )
       .unwrap();
-    let mut discoverydb = DiscoveryDB::new(GUID::new_particiapnt_guid(), None);
+    let mut discoverydb = DiscoveryDB::new(GUID::new_participant_guid(), None);
 
     let (notification_sender, _notification_receiver) = mio_extras::channel::sync_channel(100);
     let (status_sender, _status_receiver) =
