@@ -8,7 +8,12 @@ use log::{debug, error, info, trace};
 use socket2::{Domain, Protocol, SockAddr, Socket, Type};
 use bytes::{Bytes, BytesMut};
 
-use crate::network::util::get_local_multicast_ip_addrs;
+use crate::{
+  network::util::{
+    get_local_multicast_ip_addrs, get_local_multicast_locators, get_local_unicast_locators,
+  },
+  structure::locator::Locator,
+};
 
 const MAX_MESSAGE_SIZE: usize = 64 * 1024; // This is max we can get from UDP.
 const MESSAGE_BUFFER_ALLOCATION_CHUNK: usize = 256 * 1024; // must be >= MAX_MESSAGE_SIZE
@@ -31,7 +36,7 @@ impl Drop for UDPListener {
         .leave_multicast_v4(&mcg, &Ipv4Addr::UNSPECIFIED)
         .unwrap_or_else(|e| {
           error!("leave_multicast_group: {:?}", e);
-        })
+        });
     }
   }
 }
@@ -82,14 +87,17 @@ impl UDPListener {
     Ok(mio_socket)
   }
 
-  // Note that this typically does not give the local IP address, but
-  // "0.0.0.0", which means we are listening to any address.
-  pub fn to_socketaddr(&self) -> io::Result<SocketAddr> {
-    self.socket.local_addr()
+  pub fn to_locator_address(&self) -> io::Result<Vec<Locator>> {
+    let local_port = self.socket.local_addr()?.port();
+
+    match self.multicast_group {
+      Some(_ipv4_addr) => Ok(get_local_multicast_locators(local_port)),
+      None => Ok(get_local_unicast_locators(local_port)),
+    }
   }
 
   pub fn new_unicast(host: &str, port: u16) -> io::Result<UDPListener> {
-    let mio_socket = Self::new_listening_socket(host, port, false)?;
+    let mio_socket = Self::new_listening_socket(host, port, true)?;
 
     Ok(UDPListener {
       socket: mio_socket,
@@ -166,7 +174,7 @@ impl UDPListener {
       // This is safe, because we just checked that there is enough capacity.
       // We do not read undefined data, because next the recv call in messages()
       // will overwrite this space and truncate the rest away.
-      self.receive_buffer.set_len(MAX_MESSAGE_SIZE)
+      self.receive_buffer.set_len(MAX_MESSAGE_SIZE);
     }
     trace!(
       "ensure_receive_buffer_capacity - {} bytes left",
